@@ -519,11 +519,22 @@ class StreamInfo(TypedDict):
     video: VideoStreamOptions
 
 
-class PrebufferState(TypedDict):
-    state: bool
-    url: NotRequired[Optional[str]]
+class BasePrebufferState(TypedDict):
+    maxDuration: int
+    availableDuration: int
 
 
+class PrebufferStateTrue(BasePrebufferState):
+    state: bool
+    url: str
+
+
+class PrebufferStateFalse(BasePrebufferState):
+    state: bool
+
+
+PrebufferConfig = Union[PrebufferStateTrue, PrebufferStateFalse]
+
 PrebufferContainer = Literal["mpegts", "mp4"]
 
 
@@ -563,20 +574,11 @@ class CameraSource(Protocol):
     urls: StreamUrls
     # end
 
-    @overload
     async def update_prebuffering_state(
-        self, container: PrebufferContainer, state: Literal[False]
+        self, container: PrebufferContainer, state: PrebufferConfig
     ) -> None: ...
-    @overload
-    async def update_prebuffering_state(
-        self, container: PrebufferContainer, state: Literal[True], url: str
-    ) -> None: ...
-    async def update_prebuffering_state(
-        self, container: PrebufferContainer, state: bool, url: Optional[str] = None
-    ) -> None: ...
-
-    def get_prebuffering_state(self, container: PrebufferContainer) -> PrebufferState: ...
-    def on_prebuffering(self, container: PrebufferContainer) -> Observable[PrebufferState]: ...
+    def get_prebuffering_state(self, container: PrebufferContainer) -> PrebufferConfig: ...
+    def on_prebuffering(self, container: PrebufferContainer) -> Observable[PrebufferConfig]: ...
     async def get_stream_info(self) -> Optional[StreamInfo]: ...
 
 
